ncrar\_audio package
====================

Subpackages
-----------

.. toctree::
   :maxdepth: 4

   ncrar_audio.io

Submodules
----------

.. toctree::
   :maxdepth: 4

   ncrar_audio.babyface
   ncrar_audio.cpod
   ncrar_audio.dante
   ncrar_audio.osc_client
   ncrar_audio.sound_device
   ncrar_audio.triggers
   ncrar_audio.version

Module contents
---------------

.. automodule:: ncrar_audio
   :members:
   :undoc-members:
   :show-inheritance:
